package admin_role

import (
	"github.com/gin-gonic/gin"
	"go-micro.dev/v4/client"
	"sghgogs.com/sghblog/authorization-client/api/admin_role"
	"sghgogs.com/sghblog/authorization-client/utils"
	"sghgogs.com/sghblog/authorization-client/utils/baseservice"
	pb "sghgogs.com/sghblog/authorization-service/proto"
)

type AdminRole struct {
	*baseservice.BaseService
}

func NewAdminRoleRouter(namespace string, client client.Client) *AdminRole {
	return &AdminRole{
		BaseService: &baseservice.BaseService{
			Namespace: namespace,
			Client:    client,
		},
	}
}

func (svc *AdminRole) RegisterRoutes(r *gin.Engine) {
	api := admin_role.ApiAdminRole{}
	service := pb.NewAdminRoleService(svc.Namespace, svc.Client)
	api.Service = service
	svc.registerAdminRoleRoutes(r, "/v1/api", &api)
}
func (svc *AdminRole) registerAdminRoleRoutes(r *gin.Engine, path string, api *admin_role.ApiAdminRole) {
	v1 := r.Group(path)
	{
		v1.GET("/admin/role/:roleID", utils.TokenAuthMiddleware(), api.GetAdminRole)
		v1.GET("/admin/roles", utils.TokenAuthMiddleware(), api.ListAdminRoles)
		v1.GET("/admin/role/labels", utils.TokenAuthMiddleware(), api.RetrieveEnabledRoles)
		v1.POST("/admin/role", utils.TokenAuthMiddleware(), api.CreateAdminRole)
		v1.DELETE("/admin/role/:roleID", utils.TokenAuthMiddleware(), api.DeleteAdminRole)
		v1.PUT("/admin/role/:roleID", utils.TokenAuthMiddleware(), api.UpdateAdminRole)
		v1.PUT("/admin/role/:roleID/toggle", utils.TokenAuthMiddleware(), api.ToggleAdminRole)
	}
}
